@@ -1,9 +1,12 @@
 from .store_file import store_file
 from .load_file import load_file
+from .request_file_experimental import request_file_experimental
 from .store_file_local import store_file_local
+from .link_file import link_file
 from .cat_file import cat_file
 from .core import store_text, store_json, store_npy, store_pkl
 from .core import load_text, load_json, load_npy, load_pkl
+from .core import request_text_experimental, request_json_experimental, request_npy_experimental, request_pkl_experimental
 from .core import store_text_local, store_json_local, store_npy_local, store_pkl_local
 from .load_bytes import load_bytes
 from .get_kachery_cloud_dir import get_kachery_cloud_dir
@@ -16,4 +19,6 @@ from .get_project_id import get_project_id
 from .mutable import get_mutable, set_mutable
 from .mutable_local import get_mutable_local, set_mutable_local
 from .TemporaryDirectory import TemporaryDirectory
-from ._sha1_of_dict import sha1_of_dict
\ No newline at end of file
+from ._sha1_of_dict import sha1_of_dict
+from .encrypt_uri import encrypt_uri, decrypt_uri
+from .share_local_files_experimental import share_local_files_experimental
\ No newline at end of file
